==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-clock/clock_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation>&lt;basée sur locale&gt;</translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <location filename="../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation>Paramétrage de l&apos;horloge</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Heure</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>&amp;Montrer les secondes</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>Style 12 &amp;heures</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation>&amp;Utiliser UTC</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation>&amp;Format de la date</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation>&amp;Ne pas afficher la date</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation>Afficher la date a&amp;vant l&apos;heure</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation>Afficher la date a&amp;près l&apos;heure</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation>Afficher la date &amp;sous l&apos;heure, sur une nouvelle ligne</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation>Premier jour de la semaine</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation>Orientation</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>&amp;Rotation automatique quand le tableau est vertical</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation>Saisie d&apos;un format de date personnalisé</translation>
    </message>
    <message>
        <location filename="../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation>Interprétation des séquences pour le format de la date :

d	le jour du mois, un nombre sans zéro de début (1 to 31)
dd	le jour du mois, un nombre avec un zéro de débu éventuel (01 to 31)
ddd	le jour de la semaine, en abréviation locale (ex. &apos;Lun&apos; à &apos;Dim&apos;).
dddd	le jour de la semaine, non abrégé (ex. &apos;Lundi&apos; à &apos;Dimanche&apos;).
M	le mois, un nombre sans zéro de débu (1-12)
MM	le mois, un nombre avec un zéro de débu éventuel (01-12)
MMM	le mois, en abréviation locale (ex. &apos;Jan&apos; à &apos;Déc&apos;).
MMMM	le mois, non abrégée (ex. &apos;Janvier&apos; à &apos;Décembre&apos;).
yy	l&apos;année, nombre à deux digits (00-99)
yyyy	l&apos;année, nombre à quatre digits

Toute autre saisie sera considérée comme étant du texte.
Toute séquence de caractères inclue dans des guillemets simples (&apos;)
sera également considérée comme étant du texte et non comme une expression.


Format de date personnalisé :</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-clock/clock_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation>&lt;basée sur locale&gt;</translation>
    </message>
</context>
<context>
    <name>LXQtClock</name>
    <message>
        <location filename="../../../lxqtclock.cpp" line="57"/>
        <source>Date&amp;Time (clock) plugin is deprecated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="58"/>
        <source>The &lt;strong&gt;clock&lt;/strong&gt; plugin is deprecated and will be removed in future version of LXQt. Consider replacing it with &lt;strong&gt;worldclock&lt;/strong&gt;.&lt;br/&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="60"/>
        <source>don&apos;t show this again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation>Paramétrage de l&apos;horloge</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Heure</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>&amp;Montrer les secondes</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>Style 12 &amp;heures</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation>&amp;Utiliser UTC</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation>&amp;Format de la date</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation>&amp;Ne pas afficher la date</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation>Afficher la date a&amp;vant l&apos;heure</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation>Afficher la date a&amp;près l&apos;heure</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation>Afficher la date &amp;sous l&apos;heure, sur une nouvelle ligne</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation>Premier jour de la semaine</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation>Orientation</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>&amp;Rotation automatique quand le tableau est vertical</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation>Saisie d&apos;un format de date personnalisé</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation>Interprétation des séquences pour le format de la date :

d	le jour du mois, un nombre sans zéro de début (1 to 31)
dd	le jour du mois, un nombre avec un zéro de débu éventuel (01 to 31)
ddd	le jour de la semaine, en abréviation locale (ex. &apos;Lun&apos; à &apos;Dim&apos;).
dddd	le jour de la semaine, non abrégé (ex. &apos;Lundi&apos; à &apos;Dimanche&apos;).
M	le mois, un nombre sans zéro de débu (1-12)
MM	le mois, un nombre avec un zéro de débu éventuel (01-12)
MMM	le mois, en abréviation locale (ex. &apos;Jan&apos; à &apos;Déc&apos;).
MMMM	le mois, non abrégée (ex. &apos;Janvier&apos; à &apos;Décembre&apos;).
yy	l&apos;année, nombre à deux digits (00-99)
yyyy	l&apos;année, nombre à quatre digits

Toute autre saisie sera considérée comme étant du texte.
Toute séquence de caractères inclue dans des guillemets simples (&apos;)
sera également considérée comme étant du texte et non comme une expression.


Format de date personnalisé :</translation>
    </message>
</context>
</TS>
